#!/bin/bash

set -e

TAR="tar"
CP="cp -v"

PACKAGE_NAME="arta-synergy-extensions-import"
UPSTREAM_VERSION="1.0"
DEFAULT_REPO="extensions"
DEFAULT_URGENCY="low"
AUTHOR="Technology Development Department <tdd@arta.pro>"
CHANGELOG="dpkg/debian/changelog"

SYNERGYPATH="opt/synergy"
JBOSSPATH="${SYNERGYPATH}/jboss"
JBOSSDEPLOY="${JBOSSPATH}/standalone/deployments"
REVISION_LETTER="z"
DESTINATION="${JBOSSDEPLOY}"

DEFAULT_REPO=$1
if [[ $1 == *"master"* ]]
then
    DEFAULT_REPO="ier"
    REVISION_LETTER="r"
fi

if [[ $1 == *"extensions"* ]]
then
 #  DEFAULT_REPO="$PRODUCT-$UPSTREAM_VERSION"
   REVISION_LETTER="r"
fi

PKG_DIR="PACKAGE"
DSTDIR="${PKG_DIR}/${PACKAGE_NAME}"
VERSIONS_DIR="${DSTDIR}/src/opt/synergy/versions"
BUILD_NUMBER=$(date +"%y%m%d.%H%M%S")
BUILD_TIME=$(date +%F_%H:%m)
PACKAGE_VERSION="${UPSTREAM_VERSION}-${REVISION_LETTER}1~${BUILD_NUMBER}"

rm -rf "${PKG_DIR}"
mkdir -p "${DSTDIR}"
#mkdir -p "${DSTDIR}/src/${DESTINATION}"
mkdir -p "${DSTDIR}/src/${SYNERGYPATH}/extensions/import/hamming"
mkdir -p "${DSTDIR}/src/${SYNERGYPATH}/extensions/import/minsky"
mkdir -p "${DSTDIR}/src/usr/share/doc/${PACKAGE_NAME}"
# For kibana plugins
#mkdir -p "${DSTDIR}/src/usr/share"
#mkdir -p "$VERSIONS_DIR"

$TAR --exclude-vcs -c -C dpkg debian | $TAR xv -C "$DSTDIR"
$CP -a dpkg/Makefile "$DSTDIR"

$CP -a "wars/hamming/import.war" "${DSTDIR}/src/${SYNERGYPATH}/extensions/import/hamming"
$CP -a "wars/minsky/import.war" "${DSTDIR}/src/${SYNERGYPATH}/extensions/import/minsky"
$CP -a "dpkg/debian/copyright" "${DSTDIR}/src/usr/share/doc/${PACKAGE_NAME}"
$CP -a "dpkg/build.gradle" "${DSTDIR}"

# Generating changelog entry
rm -f "$DSTDIR/changelog.entry"
touch "$DSTDIR/changelog.entry"
echo "$PACKAGE_NAME ($PACKAGE_VERSION) ${DEFAULT_REPO}; urgency=${DEFAULT_URGENCY}" >> "$DSTDIR/changelog.entry"
echo "" >> "$DSTDIR/changelog.entry" >> "$DSTDIR/changelog.entry"
echo "  * Automatic build with number ${BUILD_NUMBER} ($BUILD_TIME)" >> "$DSTDIR/changelog.entry"
echo "" >> "${DSTDIR}/changelog.entry"
echo " -- ${AUTHOR}  $(date -R)" >> "$DSTDIR/changelog.entry"
echo "" >> "$DSTDIR/changelog.entry"
sed -i 's/import_version/'"$PACKAGE_VERSION"'/' "${DSTDIR}/build.gradle"
cat "$DSTDIR/changelog.entry" $CHANGELOG > "$DSTDIR/debian/changelog"
rm "$DSTDIR/changelog.entry"
$CP -a "$DSTDIR/debian/changelog" "$DSTDIR/src/usr/share/doc/${PACKAGE_NAME}/changelog.Debian"
gzip "$DSTDIR/src/usr/share/doc/${PACKAGE_NAME}/changelog.Debian"

mkdir -p $VERSIONS_DIR
echo "$PACKAGE_VERSION ($1)" > "$VERSIONS_DIR/$PACKAGE_NAME"
