package kz.arta.ext.sap.db;

import kz.arta.ext.sap.util.ConnectionPool;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.naming.NamingException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

/**
 *
 * Пример класса для работы с СУБД
 * использует соединение, указанное в @{@link ConnectionPool}
 */
public class ClientManager {

    private static final Logger LOGGER = LoggerFactory.getLogger(ClientManager.class);

    public static void log(Object logItem) {
        Connection con = null;
        try {
            con = ConnectionPool.getConnection();

            PreparedStatement st = con.prepareStatement("INSERT INTO log(logged, clientid, hostname, extip, localip) VALUES (CURRENT_TIMESTAMP, ?, ?, ?, ?)");

            st.setString(1, "clientId");
            st.setString(2, "hostname");
            st.setString(3, "extip");
            st.setString(4, "localip");

            st.execute();

        } catch (SQLException | NamingException e) {
            LOGGER.error("", e);
        } finally {
            ConnectionPool.close(con);
        }
    }

    public static String getFormDefinition(String registryCode) {
        Connection con = null;
        try {
            con = ConnectionPool.getConnection();

            PreparedStatement ps = con.prepareStatement("SELECT asf_definition.definition FROM asf_definition JOIN registries ON registries.formid = asf_definition.uuid WHERE registries.code = ? ");
            ps.setString(1, registryCode);
            ResultSet rs = ps.executeQuery();

            while (rs.next()) {
                return "{" + rs.getString("asf_definition.definition") + "}";
            }

        } catch (SQLException | NamingException e) {
            LOGGER.error("", e);
        } finally {
            ConnectionPool.close(con);
        }

        return null;
    }
}